caellion-python-commons: caellion.pycommons.encoding.base36 Namespace Reference

caellion-python-commons

Classes
caellion.pycommons.encoding.base36 Namespace Reference

This module provides utlilities related to converting to/from base36 encoding. More...

## Classes
class | InvalidCustomCharsetLengthException
| This exception is raised when custom character set length . More...
class | InvalidCustomCharsetException
| This exception is raised when more than exactly one instance of a given field is contained within field list. More...
class | InvalidInputStringException
| This exception is raised when encountering a character not defined in custom charset in input string. More...
class | NumberNotPositiveOrZeroException
| This exception is raised when non-positive integer is passed to encode function. More...
class | ValueTooLargeException
| This exception is raised when encountering an integer over maximum size of 16 bytes. More...
class | Base36Coder
| This class provides methods allowing conversion between integer, hexadecimal integer and base36 strings. More...

## Detailed Description

This module provides utlilities related to converting to/from base36 encoding.